@@ -247,8 +247,8 @@ tunable.step_isomap <- function(x, ...) {
   tibble::tibble(
     name = c("num_terms", "neighbors"),
     call_info = list(
-      list(pkg = "dials", fun = "num_terms", range = c(1, 4)),
-      list(pkg = "dials", fun = "neighbors", range = c(1, 15))
+      list(pkg = "dials", fun = "num_terms", range = c(1L, 4L)),
+      list(pkg = "dials", fun = "neighbors", range = c(1L, 15L))
     ),
     source = "recipe",
     component = "step_isomap",
