@@ -34,7 +34,7 @@
 #'     half_length = Sepal.Length / 2
 #'   )
 #'
-#' prepped <- prep(rec, training = iris %>% slice(1:75), retain = TRUE)
+#' prepped <- prep(rec, training = iris %>% slice(1:75))
 #'
 #' library(dplyr)
 #'
@@ -70,7 +70,7 @@
 #'     bad_approach = Sepal.Width * const,
 #'     best_approach = Sepal.Width * !!const
 #'   ) %>%
-#'   prep(training = iris, retain = TRUE)
+#'   prep(training = iris)
 #'
 #' juice(qq_rec, contains("appro")) %>% slice(1:4)
 #'
@@ -135,7 +135,8 @@ bake.step_mutate <- function(object, new_data, ...) {
 print.step_mutate <-
   function(x, width = max(20, options()$width - 35), ...) {
     cat("Variable mutation for ",
-        paste0(names(x$inputs), collapse = ", "))
+        paste0(names(x$inputs), collapse = ", "),
+        sep = "")
     if (x$trained) {
       cat(" [trained]\n")
     } else {
