@@ -26,7 +26,7 @@
 #' @concept preprocessing
 #' @concept basis_expansion
 #' @export
-#' @details `step_ns` can new features from a single variable
+#' @details `step_ns` can create new features from a single variable
 #'  that enable fitting routines to model this variable in a
 #'  nonlinear manner. The extent of the possible nonlinearity is
 #'  determined by the `df` or `knot` arguments of
@@ -34,6 +34,7 @@
 #'  from the data and new columns are added. The naming convention
 #'  for the new variables is `varname_ns_1` and so on.
 #' @examples
+#' library(modeldata)
 #' data(biomass)
 #'
 #' biomass_tr <- biomass[biomass$dataset == "Training",]
@@ -114,7 +115,7 @@ prep.step_ns <- function(x, training, info = NULL, ...) {
   opt <- x$options
   opt$df <- x$deg_free
   obj <- lapply(training[, col_names], ns_wrapper, opt)
-  for (i in seq(along = col_names))
+  for (i in seq(along.with = col_names))
     attr(obj[[i]], "var") <- col_names[i]
   step_ns_new(
     terms = x$terms,
@@ -183,7 +184,7 @@ tunable.step_ns <- function(x, ...) {
   tibble::tibble(
     name = c("deg_free"),
     call_info = list(
-      list(pkg = "dials", fun = "deg_free", range = c(3, 15))
+      list(pkg = "dials", fun = "spline_degree", range = c(1L, 15L))
     ),
     source = "recipe",
     component = "step_ns",
