@@ -46,7 +46,7 @@
 #'   step_dummy(item) %>%
 #'   step_ordinalscore(fail_severity)
 #'
-#' linear_values <- prep(linear_values, training = ord_data, retain = TRUE)
+#' linear_values <- prep(linear_values, training = ord_data)
 #'
 #' juice(linear_values, everything())
 #'
@@ -61,7 +61,7 @@
 #'
 #' tidy(nonlin_scores, number = 2)
 #'
-#' nonlin_scores <- prep(nonlin_scores, training = ord_data, retain = TRUE)
+#' nonlin_scores <- prep(nonlin_scores, training = ord_data)
 #'
 #' juice(nonlin_scores, everything())
 #'
@@ -111,9 +111,12 @@ prep.step_ordinalscore <-
     ord_check <-
       vapply(training[, col_names], is.ordered, c(logic = TRUE))
     if (!all(ord_check))
-      stop("Ordinal factor variables should be selected as ",
-           "inputs into this step.",
-           call. = TRUE)
+      rlang::abort(
+        paste0(
+          "Ordinal factor variables should be selected as ",
+           "inputs into this step."
+          )
+        )
     step_ordinalscore_new(
       terms = x$terms,
       role = x$role,
