@@ -37,6 +37,7 @@
 #' @seealso [step_factor2string()] [step_dummy()] [step_other()]
 #'  [step_novel()]
 #' @examples
+#' library(modeldata)
 #' data(okc)
 #'
 #' rec <- recipe(~ diet + location, data = okc)
@@ -45,8 +46,7 @@
 #'   step_string2factor(diet)
 #' make_factor <- prep(make_factor,
 #'                     training = okc,
-#'                     strings_as_factors = FALSE,
-#'                     retain = TRUE)
+#'                     strings_as_factors = FALSE)
 #'
 #' # note that `diet` is a factor
 #' juice(make_factor) %>% head
@@ -64,11 +64,11 @@ step_string2factor <-
            id = rand_id("string2factor")) {
     if (!is_tune(ordered) & !is_varying(ordered)) {
       if (!is.logical(ordered) || length(ordered) != 1) {
-        stop("`ordered` should be a single logical variable")
+        rlang::abort("`ordered` should be a single logical variable")
       }
     }
     if ((!is.null(levels) & !is.character(levels)) | is.list(levels)) {
-      stop("`levels` should be NULL or a single character vector")
+      rlang::abort("`levels` should be NULL or a single character vector")
     }
 
     add_step(
@@ -112,10 +112,11 @@ prep.step_string2factor <- function(x, training, info = NULL, ...) {
       logical(1)
     )
   if (any(!str_check))
-    stop(
-      "The following variables are not character vectors: ",
-      paste0("`", names(str_check)[!str_check], "`", collapse = ", "),
-      call. = FALSE
+    rlang::abort(
+      paste0(
+        "The following variables are not character vectors: ",
+        paste0("`", names(str_check)[!str_check], "`", collapse = ", ")
+      )
     )
 
   if (is.null(x$levels)) {
